==> netbeans_8.0.2%2Bdfsg1.orig.tar.xz: netbeans-8.0.2/dlight.remote.impl/test/unit/src/org/netbeans/modules/remote/impl/fs/WrongCreationEventsTestCase.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */
package org.netbeans.modules.remote.impl.fs;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import junit.framework.Test;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.netbeans.modules.nativeexecution.api.util.ProcessUtils;
import org.netbeans.modules.nativeexecution.test.ForAllEnvironments;
import org.netbeans.modules.nativeexecution.test.RcFile.FormatException;
import org.netbeans.modules.remote.spi.FileSystemProvider;
import org.netbeans.modules.remote.test.RemoteApiTest;
import org.openide.filesystems.*;

/**
 * There hardly is a way to unit test remote operations.
 * This is just an entry point for manual validation.
 *
 * @author Vladimir Kvashin
 */
public class WrongCreationEventsTestCase extends RemoteFileTestBase {

    public WrongCreationEventsTestCase(String testName, ExecutionEnvironment execEnv) throws IOException, FormatException {
        super(testName, execEnv);
    }

    @ForAllEnvironments
    public void testChangeDirectoryLink() throws Exception {
        String baseDir = null;
        try {
            final List<FileEvent> eventList = Collections.synchronizedList(new ArrayList<FileEvent>());

            FileChangeListener listener = new FileChangeListener() {
                @Override
                public void fileChanged(FileEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileAttributeChanged(FileAttributeEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileDataCreated(FileEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileFolderCreated(FileEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileRenamed(FileRenameEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileDeleted(FileEvent fe) {
                    eventList.add(fe);
                }
            };

            RemoteFileSystemManager.getInstance().resetFileSystem(execEnv);
            baseDir = mkTemp(execEnv, true);
            String creationScript =
                    "cd " + baseDir + "; " +
                    "echo 123 > file_1; " +
                    "echo abc > file_2";

            ProcessUtils.ExitStatus res1 = ProcessUtils.execute(execEnv, "sh", "-c", creationScript);
            assertEquals("Error executing script \"" + creationScript + "\": " + res1.error, 0, res1.exitCode);

            FileSystemProvider.addRecursiveListener(listener, fs, "/");
            FileObject baseDirFO = getFileObject(baseDir);
            assertTrue("There should be no events (1)", eventList.isEmpty());
            baseDirFO.getChildren();
            assertTrue("There should be no events (2)", eventList.isEmpty());
        } finally {
            removeRemoteDirIfNotNull(baseDir);
        }
    }

    public static Test suite() {
        return RemoteApiTest.createSuite(WrongCreationEventsTestCase.class);
    }
}

==> netbeans_8.2%2Bdfsg1.orig.tar.xz: netbeans-8.2/dlight.remote.impl/test/unit/src/org/netbeans/modules/remote/impl/fs/WrongCreationEventsTestCase.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */
package org.netbeans.modules.remote.impl.fs;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import junit.framework.Test;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.netbeans.modules.nativeexecution.api.util.ProcessUtils;
import org.netbeans.modules.nativeexecution.test.ForAllEnvironments;
import org.netbeans.modules.nativeexecution.test.RcFile.FormatException;
import org.netbeans.modules.remote.spi.FileSystemProvider;
import org.netbeans.modules.remote.test.RemoteApiTest;
import org.openide.filesystems.*;

/**
 * There hardly is a way to unit test remote operations.
 * This is just an entry point for manual validation.
 *
 * @author Vladimir Kvashin
 */
public class WrongCreationEventsTestCase extends RemoteFileTestBase {

    public WrongCreationEventsTestCase(String testName, ExecutionEnvironment execEnv) throws IOException, FormatException {
        super(testName, execEnv);
    }

    @ForAllEnvironments
    public void testChangeDirectoryLink() throws Exception {
        String baseDir = null;
        try {
            final List<FileEvent> eventList = Collections.synchronizedList(new ArrayList<FileEvent>());

            FileChangeListener listener = new FileChangeListener() {
                @Override
                public void fileChanged(FileEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileAttributeChanged(FileAttributeEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileDataCreated(FileEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileFolderCreated(FileEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileRenamed(FileRenameEvent fe) {
                    eventList.add(fe);
                }

                @Override
                public void fileDeleted(FileEvent fe) {
                    eventList.add(fe);
                }
            };

            RemoteFileSystemManager.getInstance().resetFileSystem(execEnv, false);
            baseDir = mkTemp(execEnv, true);
            String creationScript =
                    "cd " + baseDir + "; " +
                    "echo 123 > file_1; " +
                    "echo abc > file_2";

            ProcessUtils.ExitStatus res1 = ProcessUtils.execute(execEnv, "sh", "-c", creationScript);
            assertEquals("Error executing script \"" + creationScript + "\": " + res1.getErrorString(), 0, res1.exitCode);

            FileSystemProvider.addRecursiveListener(listener, fs, "/");
            FileObject baseDirFO = getFileObject(baseDir);
            assertTrue("There should be no events (1)", eventList.isEmpty());
            baseDirFO.getChildren();
            assertTrue("There should be no events (2)", eventList.isEmpty());
        } finally {
            removeRemoteDirIfNotNull(baseDir);
        }
    }

    public static Test suite() {
        return RemoteApiTest.createSuite(WrongCreationEventsTestCase.class);
    }
}
